#ifndef __AxMenuMailBoxView_H__
#define __AxMenuMailBoxView_H__
//=============================================================================
/*
 * See the file README in the main directory for a description of
 * this software, copyright information, and how to reach the author.
 *
 * Author: alex
 * Date:   17.11.2003
 *
 * Last modfied:
 *   $Author: alex $
 *   $Date: 2013-11-02 09:26:18 +0100 (Sa, 02 Nov 2013) $
 */
//=============================================================================

//=============================================================================
//     includes
//=============================================================================

//----- qt --------------------------------------------------------------------
//----- CORBA -----------------------------------------------------------------
//----- C++ -------------------------------------------------------------------
//----- C ---------------------------------------------------------------------
//----- vdr -------------------------------------------------------------------
#include <vdr/osd.h>

//----- AxLib -----------------------------------------------------------------
#include <Ax/Mail/Globals.h>
#include <Ax/Vdr/OsdMenu.h>

//----- local -----------------------------------------------------------------
#include "AxPluginSetup.h"

//----- other includes --------------------------------------------------------

//=============================================================================
//     forward declarations
//=============================================================================
class AxPluginMailBox;
namespace Ax   {
namespace Mail {
  class MailBox;
}
}

//=============================================================================
//     class AxMenuMailBoxView
//=============================================================================
/** Menu to select a mail account and to call the mail-list-view.
 */
class AxMenuMailBoxView : public Ax::Vdr::OsdMenu
{
    //-------------------------------------------------------------------------
    //     typedefs
    //-------------------------------------------------------------------------
    typedef Ax::Vdr::OsdMenu  PARENT;
    typedef AxMenuMailBoxView MYSELF;

  protected:
    //-------------------------------------------------------------------------
    //     enums
    //-------------------------------------------------------------------------
    enum AxEAction
    {
      A_FIRST          = PARENT::A_LAST
    , A_OPEN_MAILBOX   = A_FIRST
    , A_REFRESH_CURRENT
    , A_REFRESH_ALL
    , A_SHOW_LOG
    , A_LAST
    };

  public:
    //-------------------------------------------------------------------------
    //     AxMenuMailBoxView()
    //-------------------------------------------------------------------------
    /** Constructor
     *
     *  VDR takes responsibility for the created items.
     */
    AxMenuMailBoxView(AxPluginMailBox *thePlugin);

    //-------------------------------------------------------------------------
    //     ~AxMenuMailBoxView()
    //-------------------------------------------------------------------------
    /** Destructor
     */
    virtual ~AxMenuMailBoxView();

    //-------------------------------------------------------------------------
    //     MenuKind()
    //-------------------------------------------------------------------------
    virtual const char* MenuKind() { return "MenuMailboxView"; }

    //-------------------------------------------------------------------------
    //     processAction()
    //-------------------------------------------------------------------------
    virtual eOSState processAction(const Ax::Vdr::Action &theAction, eOSState = osUnknown);

    //-------------------------------------------------------------------------
    //     doOpenCurrentMailBox()
    //-------------------------------------------------------------------------
    eOSState doOpenCurrentMailBox();

    //-------------------------------------------------------------------------
    //     getCurrentMailBox()
    //-------------------------------------------------------------------------
    Ax::Mail::MailBox *getCurrentMailBox() const;

  protected:
    //-------------------------------------------------------------------------
    //     updateActions()
    //-------------------------------------------------------------------------
    void updateActions();

    //-------------------------------------------------------------------------
    //     actionCheckMailBoxes()
    //-------------------------------------------------------------------------
    void checkMailBoxes();

    //-------------------------------------------------------------------------
    //     informSubOSDClosed()
    //-------------------------------------------------------------------------
    virtual void informSubOSDClosed(const Ax::Vdr::Action &theAction, eKeys theKey);

    //-------------------------------------------------------------------------
    //     informCurrentChanged()
    //-------------------------------------------------------------------------
    virtual void informCurrentChanged(int theOldCurrent);

  private:
    //-------------------------------------------------------------------------
    //     checkMailBox()
    //-------------------------------------------------------------------------
    void checkMailBox(int theIndex);

    //-------------------------------------------------------------------------
    //     attributes
    //-------------------------------------------------------------------------
    AxPluginMailBox *myPlugin;

}; // class AxMenuMailBoxView

#endif

